# django-better-search
<i>This repo is heavily influenced by [django-admin-search](https://github.com/shinneider/django-admin-search) and copies some of the components as well.</i>

This repo implements search on Django admin page differently. It generates different search boxes for separate fields and doesn't treat all of those fields as string.

## Requirements
This app requires the following:

* Django >= 3.2

## Usage
This project is <b>not ready yet for any use</b>.